@@ -3,6 +3,7 @@ import asyncio
 import six
 from six.moves import urllib
 
+from .exceptions import EngineIOError
 from . import packet
 from . import server
 from . import asyncio_socket
@@ -55,6 +56,7 @@ class AsyncServer(server.Server):
 
     def attach(self, app, engineio_path='engine.io'):
         """Attach the Engine.IO server to an application."""
+        engineio_path = engineio_path.strip('/')
         self._async['create_route'](app, self, '/{}/'.format(engineio_path))
 
     async def send(self, sid, data, binary=None):
@@ -152,7 +154,7 @@ class AsyncServer(server.Server):
                     try:
                         await socket.handle_post_request(environ)
                         r = self._ok()
-                    except ValueError:
+                    except EngineIOError:
                         r = self._bad_request()
             else:
                 self.logger.warning('Method %s not supported', method)
