@@ -2,6 +2,7 @@ import asyncio
 import time
 import six
 
+from . import exceptions
 from . import packet
 from . import payload
 from . import socket
@@ -44,7 +45,7 @@ class AsyncSocket(socket.Socket):
         elif pkt.packet_type == packet.CLOSE:
             await self.close(wait=False, abort=True)
         else:
-            raise ValueError
+            raise exceptions.UnknownPacketError()
 
     async def send(self, pkt):
         """Send a packet to the client."""
@@ -81,7 +82,7 @@ class AsyncSocket(socket.Socket):
         """Handle a long-polling POST request from the client."""
         length = int(environ.get('CONTENT_LENGTH', '0'))
         if length > self.server.max_http_buffer_size:
-            raise ValueError()
+            raise exceptions.ContentTooLongError()
         else:
             body = await environ['wsgi.input'].read(length)
             p = payload.Payload(encoded_payload=body)
@@ -179,7 +180,7 @@ class AsyncSocket(socket.Socket):
             pkt = packet.Packet(encoded_packet=p)
             try:
                 await self.receive(pkt)
-            except ValueError:
+            except exceptions.UnknownPacketError:
                 pass
 
         await self.queue.put(None)  # unlock the writer task so it can exit
